SubtreeCommand

Enum SubtreeCommand 

pub enum SubtreeCommand {
    Add {
        path: PathBuf,
        remote: String,
    },
    Diff {
        path: PathBuf,
    },
    Pull {
        path: PathBuf,
    },
    Remove {
        path: PathBuf,
    },
    Ls,
}
Command that goes after tagit sub

Variants



Add

Start tracking a new subtree

If remote or subtree are already present, keeps them as is and pulls

Fields

path: PathBuf

Path relative to .tagit/sub/

remote: String

Url of the remote



Diff

Diff local and remote versions of the subtree

Fields

path: PathBuf

Path relative to .tagit/sub/



Pull

Pull changes for subtrees

To pull for all subtrees use tagit sub pull '*'

Fields

path: PathBuf

Path relative to .tagit/sub/



Remove

Stop tracking a subtree

This just removes the remote

Fields

path: PathBuf

Path relative to .tagit/sub/



Ls

List all the subtrees

All subdirectories of .tagit/sub/ which have a corresponding remote