pub enum SubtreeCommand {
Add {
path: PathBuf,
remote: String,
},
Diff {
path: PathBuf,
},
Pull {
path: PathBuf,
},
Remove {
path: PathBuf,
},
Ls,
}Expand description
Command that goes after tagit sub
Variants
Add
Start tracking a new subtree
If remote or subtree are already present, keeps them as is and pulls
Diff
Diff local and remote versions of the subtree
Pull
Pull changes for subtrees
To pull for all subtrees use tagit sub pull '*'
Remove
Stop tracking a subtree
This just removes the remote
Ls
List all the subtrees
All subdirectories of .tagit/sub/ which have a corresponding remote